%global tarball xf86-video-qxl
%global moduledir %(pkg-config xorg-server --variable=moduledir )
%global driverdir %{moduledir}/drivers

%define rel 16

# Xspice is x86_64 and ARM only since spice-server is x86_64 / ARM only
%ifarch %{ix86} x86_64 %{arm} aarch64
%define with_xspice 1
%else
%define with_xspice 0
%endif

#global gitdate 20160929
#global gitversion e13d28ee

%if 0%{?gitdate}

%define gver .%{gitdate}git%{gitversion}
%endif

Name:    x11-driver-video-qxl
Version: 0.1.5
Release: %mkrel %{rel}%{?gver}
Summary: X.org driver for QEMU QXL paravirt video
Group:   System/X11
URL:     https://www.x.org/
Source0:   http://xorg.freedesktop.org/releases/individual/driver/%{tarball}-%{version}.tar.bz2
#Source0: %{tarball}-%{gitdate}.tar.bz2
Patch1: 0001-worst-hack-of-all-time-to-qxl-driver.patch
Patch2: 0002-Xspice-Use-print-instead-of-print.patch
Patch3: 0003-Xspice-Remove-extra-space-before-assignment.patch
Patch4: 0004-Xspice-Fix-Python3-str-vs-bytes-confusion.patch
# This shebang patch is currently downstream-only
Patch5: 0005-Xspice-Adjust-shebang-to-explicitly-mention-python3.patch
Patch6: 0006-qxl-call-provider-init.patch


License: MIT


BuildRequires: make
BuildRequires: pkgconfig
BuildRequires: git-core
BuildRequires: x11-util-macros
BuildRequires: pkgconfig(xorg-server) >= 1.1.0-1
BuildRequires: spice-protocol >= 0.12.1
BuildRequires: pkgconfig(libdrm) >= 2.4.46-1
%if %{with_xspice}
BuildRequires: spice-server-devel >= 0.8.0
%endif
BuildRequires: glib2-devel
BuildRequires: libtool
BuildRequires: pkgconfig(libudev)
BuildRequires: pkgconfig(xfont2)
BuildRequires: pkgconfig(xext)
BuildRequires: pkgconfig(xv)

Requires:	x11-server-common %(xserver-sdk-abi-requires ansic)
Requires:	x11-server-common %(xserver-sdk-abi-requires videodrv)

%description
X.org driver for QEMU QXL paravirt video.

%if %{with_xspice}
%package -n    x11-server-xspice
Summary:       XSpice is an X server that can be accessed by a Spice client
Requires:	x11-server-common %(xserver-sdk-abi-requires ansic)
Requires:	x11-server-common %(xserver-sdk-abi-requires videodrv)
Requires:      x11-server-xorg
Requires:      python3

%description -n x11-server-xspice
XSpice is both an X and a Spice server.
%endif

%prep
%autosetup -S git_am -n %{tarball}-%{?gitdate:%{gitdate}}%{!?gitdate:%{version}}

# python shebangs
pathfix.py -pni "%{__python3} %{py3_shbang_opts}" scripts/Xspice

%build
autoreconf -ivf
%if %{with_xspice}
%define enable_xspice --enable-xspice
%endif
%configure --disable-static %{?enable_xspice}
%make_build

%install
%make_install

# FIXME: Remove all libtool archives (*.la) from modules directory.  This
# should be fixed in upstream Makefile.am or whatever.
find $RPM_BUILD_ROOT -regex ".*\.la$" | xargs rm -f --

%if %{with_xspice}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/X11
install -p -m 644 examples/spiceqxl.xorg.conf.example \
    $RPM_BUILD_ROOT%{_sysconfdir}/X11/spiceqxl.xorg.conf
# FIXME: upstream installs this file by default, we install it elsewhere.
# upstream should just not install it and let dist package deal with
# doc/examples.
rm -f $RPM_BUILD_ROOT/usr/share/doc/xf86-video-qxl/spiceqxl.xorg.conf.example
%if !%{with_xspice}
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/X11/spiceqxl.xorg.conf
%endif
%endif

%files
%doc COPYING README
%{driverdir}/qxl_drv.so


%if %{with_xspice}
%files -n x11-server-xspice
%doc COPYING README.xspice README examples/spiceqxl.xorg.conf.example
%config(noreplace) %{_sysconfdir}/X11/spiceqxl.xorg.conf
%{_bindir}/Xspice
%{driverdir}/spiceqxl_drv.so
%endif


%changelog
* Mon Dec 07 2020 tv <tv> 0.1.5-16.mga8
+ Revision: 1654246
- prevent crashes when multiple QXL devices are configured in a VM (rhbz#1428340)
- spice: Adjust shebang to explicitly mention python3
- Add missing BR
- Build on more arches

* Mon May 11 2020 wally <wally> 0.1.5-15.mga8
+ Revision: 1583212
- add patches from upstream for python3 support in Xspice
- replace deprecated %%configure2_5x
- replace deprecated %%makeinstall_std
+ danf <danf>
- Switch URLs from http: to https:
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 0.1.5-13.mga7
+ Revision: 1301763
- Mageia 7 Mass Rebuild

* Fri Mar 09 2018 tv <tv> 0.1.5-12.mga7
+ Revision: 1207643
- rebuild for xserver 1.20 RC1

* Thu Jan 05 2017 tv <tv> 0.1.5-11.mga6
+ Revision: 1080200
- new release

* Thu Nov 17 2016 tv <tv> 0.1.4-11.20160929gite13d28ee.mga6
+ Revision: 1067731
- BR x11-util-macros
- fix crash caused by attempting to access the screen pixmap before it's created
- use a git snapshot (fixes for use with xserver-1.19)
- rebuild for xserver 1.19

* Sat Jul 23 2016 tmb <tmb> 0.1.4-8.mga6
+ Revision: 1043260
- rebuild for xorg-server 1.18.4

* Tue Mar 08 2016 tv <tv> 0.1.4-7.mga6
+ Revision: 987304
- QXL driver should requires X.org ABI too

* Tue Mar 08 2016 tv <tv> 0.1.4-6.mga6
+ Revision: 987300
- sync BRs with  FC
- versionnate some BRs
- drop BR on kernel-devel
- add xpsice support on x86_64
- kill KINC hack that break xspice support
- kill dead macros
- update URL

* Sun Mar 06 2016 blino <blino> 0.1.4-5.mga6
+ Revision: 986264
- Mageia 6 Mass Rebuild

* Wed Nov 11 2015 tv <tv> 0.1.4-4.mga6
+ Revision: 902272
- submit to core/release

* Wed Nov 11 2015 tv <tv> 0.1.4-3.mga6
+ Revision: 901538
- sync patches with FC
- rebuild for new xserver

* Sat Jun 20 2015 tv <tv> 0.1.4-2.mga6
+ Revision: 835945
- rebuild for xserver 1.17

* Sun May 10 2015 tv <tv> 0.1.4-1.mga5
+ Revision: 821610
- new release, sync patches with FC

* Wed Jul 23 2014 tv <tv> 0.1.2-1.mga5
+ Revision: 656010
- new release

* Sat Jun 14 2014 tv <tv> 0.1.1-6.mga5
+ Revision: 636098
- add server managed fd support (from FC)

* Mon Jun 09 2014 tv <tv> 0.1.1-5.mga5
+ Revision: 634980
- submit to core/release

* Fri Jun 06 2014 tv <tv> 0.1.1-4.mga5
+ Revision: 633651
- rebuild for new xserver RC

* Tue Apr 15 2014 tv <tv> 0.1.1-3.mga5
+ Revision: 614324
- rebuild for new xserver

* Tue Feb 04 2014 tv <tv> 0.1.1-2.mga5
+ Revision: 582243
- rebuild for new xserver

* Fri Nov 15 2013 tv <tv> 0.1.1-1.mga4
+ Revision: 551396
- new release
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Thu May 30 2013 tv <tv> 0.1.1-0.20130514git77a1594.1.mga4
+ Revision: 433502
- sync with RH
- fix build with multiple kernels installed

* Thu May 30 2013 tv <tv> 0.1.1-0.20130312gita474a71.1.mga4
+ Revision: 433125
- submit to core/release

* Fri May 24 2013 tv <tv> 0.1.1-0.20130312gita474a71.mga4
+ Revision: 425984
- sync with RH (git snapshot + support for old revision 1 qxl device))
- BR drm-devel + kernel-devel
- fix build
- new release
- new release
- rebuild for new xserver
- rebuild for new xserver
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jun 06 2012 tmb <tmb> 0.0.17-3.mga3
+ Revision: 256459
- rebuild for core/release

* Fri Jun 01 2012 tv <tv> 0.0.17-2.mga3
+ Revision: 252969
- rebuild b/c of ia32 failure

* Wed May 30 2012 tv <tv> 0.0.17-1.mga3
+ Revision: 249795
- new release

* Tue Dec 06 2011 tmb <tmb> 0.0.16-4.mga2
+ Revision: 177483
- submit to core/release

* Sat Oct 08 2011 tv <tv> 0.0.16-3.mga2
+ Revision: 153305
- really rebuild for xserver-1.11

* Sat Oct 08 2011 tv <tv> 0.0.16-2.mga2
+ Revision: 153084
- rebuild for xserver-1.11
- BuildRequires: spice-protocol
- disable xspice
- new release
- enable-xspice

* Tue Feb 01 2011 dmorgan <dmorgan> 0.0.13-1.mga1
+ Revision: 46014
- imported package x11-driver-video-qxl

